@@ -11,11 +11,16 @@ def resultant_module(module_vector1, module_vector2, angle):
     return mt.sqrt((pow(vector1, 2)+pow(vector2, 2)+2*vector1*vector2*mt.cos(angle)))
 
 
-def vector2d_module(comp_x,comp_y):
+def vector2d_module(vetor):
+    comp_x=vetor[0]
+    comp_y=vetor[1]
     return mt.sqrt((pow(comp_x, 2)+pow(comp_y, 2)))
 
 
-def vector3d_module(comp_x, comp_y, comp_z):
+def vector3d_module(vetor):
+    comp_x=vetor[0]
+    comp_y=vetor[1]
+    comp_z=vetor[2]
     return mt.sqrt((pow(comp_x, 2)+pow(comp_y, 2))+pow(comp_z, 2))
 
 
@@ -141,4 +146,4 @@ def plot3d(lista_vetores,lista_cores,lista_limites):
                       [x[5]],
                       length=1, normalize=False, color=lista_cores[i])
 
-    plt.show()
+    plt.show()
\ No newline at end of file
